16.91. cdist-type__package_akp(7) — cdist 6.1.1 documentation

# 16.91. cdist-type__package_akp(7)

## 16.91.1. NAME

cdist-type__package_akp - Manage packages with akp

## 16.91.2. DESCRIPTION

apk is usually used on Alpine to manage packages.

## 16.91.3. REQUIRED PARAMETERS

None

## 16.91.4. OPTIONAL PARAMETERS

name
  If supplied, use the name and not the object id as the package name.
state
  Either "present" or "absent", defaults to "present"

## 16.91.5. EXAMPLES

    # Ensure zsh in installed
    __package_apk zsh --state present

    # Remove package
    __package_apk apache2 --state absent

## 16.91.6. SEE ALSO

cdist-type__package(7)

## 16.91.7. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 16.91.8. COPYING

Copyright (C) 2019 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.